@@ -559,6 +559,10 @@ totem_pl_parser_class_init (TotemPlParserClass *klass)
 				     "String representing the identifier for an entry", NULL,
 				     G_PARAM_READABLE & G_PARAM_WRITABLE);
 	g_param_spec_pool_insert (totem_pl_parser_pspec_pool, pspec, TOTEM_TYPE_PL_PARSER);
+	pspec = g_param_spec_string ("subtitle-uri", "uri",
+				     "Subtitle URI to be added", NULL,
+				     G_PARAM_READABLE & G_PARAM_WRITABLE);
+	g_param_spec_pool_insert (totem_pl_parser_pspec_pool, pspec, TOTEM_TYPE_PL_PARSER);
 }
 
 static void
@@ -1654,18 +1658,23 @@ totem_pl_parser_cleanup_xml (char *contents)
 {
 	char *needle;
 
-	while ((needle = strstr (contents, "<!--")) != NULL) {
-		while (strncmp (needle, "-->", 3) != 0) {
-			*needle = ' ';
-			needle++;
-			if (*needle == '\0')
-				break;
-		}
-		if (strncmp (needle, "-->", 3) == 0) {
-			guint i;
-			for (i = 0; i < 3; i++)
-				*(needle + i) = ' ';
+	needle = contents;
+	while ((needle = strstr (needle, "<!--")) != NULL) {
+		char *end;
+
+		/* Find end of comments */
+		end = strstr (needle, "-->");
+		/* Broken file? */
+		if (end == NULL)
+			return;
+		if (memmem (needle, end - needle,
+			    "]]>", strlen ("]]>")) != NULL) {
+			/* Advance 3 and skip */
+			needle += 3;
+			continue;
 		}
+		/* Empty the comment */
+		memset (needle, ' ', end + 3 - needle);
 	}
 }
 
@@ -1676,11 +1685,16 @@ totem_pl_parser_parse_xml_relaxed (char *contents,
 	xml_node_t* doc, *node;
 	char *encoding, *new_contents;
 	gsize new_size;
+	xml_parser_t *xml_parser;
 
 	totem_pl_parser_cleanup_xml (contents);
-	xml_parser_init (contents, size, XML_PARSER_CASE_INSENSITIVE);
-	if (xml_parser_build_tree_with_options (&doc, XML_PARSER_RELAXED | XML_PARSER_MULTI_TEXT) < 0)
+	xml_parser = xml_parser_init_r (contents, size, XML_PARSER_CASE_INSENSITIVE);
+	if (xml_parser_build_tree_with_options_r (xml_parser, &doc, XML_PARSER_RELAXED | XML_PARSER_MULTI_TEXT) < 0) {
+		xml_parser_finalize_r (xml_parser);
 		return NULL;
+	}
+
+	xml_parser_finalize_r (xml_parser);
 
 	encoding = NULL;
 	for (node = doc; node != NULL; node = node->next) {
@@ -1705,12 +1719,14 @@ totem_pl_parser_parse_xml_relaxed (char *contents,
 	}
 	g_free (encoding);
 
-	xml_parser_init (new_contents, new_size, XML_PARSER_CASE_INSENSITIVE);
-	if (xml_parser_build_tree_with_options (&doc, XML_PARSER_RELAXED | XML_PARSER_MULTI_TEXT) < 0) {
+	xml_parser = xml_parser_init_r (new_contents, new_size, XML_PARSER_CASE_INSENSITIVE);
+	if (xml_parser_build_tree_with_options_r (xml_parser, &doc, XML_PARSER_RELAXED | XML_PARSER_MULTI_TEXT) < 0) {
+		xml_parser_finalize_r (xml_parser);
 		g_free (new_contents);
 		return NULL;
 	}
 
+	xml_parser_finalize_r (xml_parser);
 	g_free (new_contents);
 
 	return doc;
@@ -2304,7 +2320,8 @@ totem_pl_parser_mime_type_from_data (gconstpointer data, int len)
 	if (mime_type != NULL &&
 	    (strcmp (mime_type, "text/plain") == 0 ||
 	     strcmp (mime_type, "application/octet-stream") == 0 ||
-	     strcmp (mime_type, "application/xml") == 0)) {
+	     strcmp (mime_type, "application/xml") == 0 ||
+	     strcmp (mime_type, "text/html") == 0)) {
 		PlaylistIdenCallback func;
 		guint i;
 
